@@ -11,8 +11,10 @@ from sqlalchemy.ext.hybrid import hybrid_property
 from typing import Union, Set, Mapping, Iterable, Tuple, FrozenSet, List
 from sqlalchemy.ext.declarative import DeclarativeMeta
 from sqlalchemy.orm import ColumnProperty, RelationshipProperty
+from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.orm.base import InspectionAttr
 from sqlalchemy.orm.interfaces import MapperProperty
+from sqlalchemy.orm.strategies import DeferredColumnLoader
 from sqlalchemy.orm.util import AliasedClass
 from sqlalchemy.sql.elements import BinaryExpression
 from sqlalchemy.sql.type_api import TypeEngine
@@ -95,6 +97,7 @@ class ModelPropertyBags:
 
         # Init bags: after every column type
         self.columns = self._init_columns(model, insp)
+        self.column_properties = self._init_column_properties(model, insp)
         self.properties = self._init_properties(model, insp)
         self.hybrid_properties = self._init_hybrid_properties(model, insp)
         self.association_proxies = self._init_association_proxies(model, insp)
@@ -104,6 +107,8 @@ class ModelPropertyBags:
         # Additional informational bags
         self.pk = self._init_primary_key(model, insp)
         self.nullable = self._init_nullable_columns(model, insp)
+        self.deferred_columns = self._init_deferred_columns(model, insp)
+        self.has_deferred_columns = len(self.deferred_columns.names) > 0
 
         # Writable entities
         self.writable_properties = self._init_writable_properties(model, insp)
@@ -125,6 +130,9 @@ class ModelPropertyBags:
         """ Initialize: Column properties """
         return DotColumnsBag(_get_model_columns(model, insp))
 
+    def _init_column_properties(self, model, insp):
+        return ColumnsBag(_get_model_column_properties(model, insp))
+
     def _init_properties(self, model, insp):
         """ Initialize: Calculated properties: @property """
         return PropertiesBag(_get_model_properties(model, insp))
@@ -161,6 +169,12 @@ class ModelPropertyBags:
                            for name, c in self.columns
                            if c.nullable})
 
+    def _init_deferred_columns(self, model, insp):
+        """ Initialize: deferred columns """
+        return ColumnsBag({name: c
+                           for name, c in self.columns
+                           if isinstance(c.property.strategy, DeferredColumnLoader)})
+
     def _init_writable_properties(self, model, insp):
         """ Initialize: writable properties """
         return PropertiesBag({name: None
@@ -658,7 +672,7 @@ class CombinedBag(_PropertiesBagBase):
             for column_name, column in bag
         }
 
-        # List of JSON columns
+        # List of JSON columnstests/t2_handlers_test.py:1115
         json_column_names = []
         for bag in self._bags.values():
             # We'll access a protected property, so got to make sure we've got the right class
@@ -731,14 +745,24 @@ class CombinedBag(_PropertiesBagBase):
 
 
 def _get_model_columns(model, ins):
-    """ Get a dict of model columns """
+    """ Get a dict of model columns. Only columns. """
     return {name: getattr(model, name)
             for name, c in ins.column_attrs.items()
-            # ignore Labels and other stuff that .items() will always yield
-            if isinstance(c.expression, Column)
+            # NOTE: for backwards compatibility, we cannot now exlude underscored properties
+            # because they are sometimes mentioned in `bundled_project` and are therefore in use
+            # if not name.startswith('_')
+            if isinstance(c.expression, Column)  # exclude column properties (SQL expressions)
             }
 
 
+def _get_model_column_properties(model, ins):
+    """ Get a dict of model column properties """
+    return {name: getattr(model, name)
+            for name, c in ins.column_attrs.items()
+            if not name.startswith('_') and
+               not isinstance(c.expression, Column)  # non-column attributes like SQL expressions
+            }
+
 def _get_model_association_proxies(model, ins):
     """ Get a dict of model association_proxy attributes """
     # Ignore AssociationProxy attrs for SA 1.2.x
