@@ -1,4 +1,3 @@
-from nplus1loader import raiseload_col, raiseload_rel, raiseload_all
 from .selectinquery import selectinquery
 from .counting_query_wrapper import CountingQuery
 from .reusable import Reusable
@@ -9,3 +8,10 @@ from .method_decorator import method_decorator, method_decorator_meta
 from .bulk import \
     EntityDictWrapper, load_many_instance_dicts, \
     model_primary_key_columns_and_names, entity_dict_has_primary_key
+
+try:
+    import nplus1loader
+except ImportError:
+    pass
+else:
+    from nplus1loader import raiseload_col, raiseload_rel, raiseload_all
